@@ -35,6 +35,16 @@ type mockAddGitClient struct {
 	GetCurrentBranchFunc  func() (string, error)
 	LogOnelineFunc        func(from, to string) (string, error)
 	RebaseInteractiveFunc func(commitCount int) error
+	RebaseCalled          bool
+	RebaseUpstream        string
+	RebaseErr             error
+	RebaseContinueCalled  bool
+	RebaseContinueErr     error
+	RebaseAbortCalled     bool
+	RebaseAbortErr        error
+	RebaseSkipCalled      bool
+	RebaseSkipErr         error
+	RevParseVerifyFunc    func(ref string) bool
 }
 
 func (m *mockAddGitClient) Add(files ...string) error {
@@ -127,6 +137,23 @@ func (m *mockAddGitClient) RebaseInteractive(commitCount int) error {
 	}
 	return nil
 }
+func (m *mockAddGitClient) Rebase(upstream string) error {
+	m.RebaseCalled = true
+	m.RebaseUpstream = upstream
+	return m.RebaseErr
+}
+func (m *mockAddGitClient) RebaseContinue() error {
+	m.RebaseContinueCalled = true
+	return m.RebaseContinueErr
+}
+func (m *mockAddGitClient) RebaseAbort() error {
+	m.RebaseAbortCalled = true
+	return m.RebaseAbortErr
+}
+func (m *mockAddGitClient) RebaseSkip() error {
+	m.RebaseSkipCalled = true
+	return m.RebaseSkipErr
+}
 func (m *mockAddGitClient) GetUpstreamBranch(_ string) (string, error) {
 	return "origin/main", nil
 }
@@ -165,7 +192,12 @@ func (m *mockAddGitClient) GetAheadBehindCount(_, _ string) (string, error) {
 }
 func (m *mockAddGitClient) GetVersion() (string, error)    { return "test-version", nil }
 func (m *mockAddGitClient) GetCommitHash() (string, error) { return "test-commit", nil }
-func (m *mockAddGitClient) RevParseVerify(_ string) bool   { return true }
+func (m *mockAddGitClient) RevParseVerify(ref string) bool {
+	if m.RevParseVerifyFunc != nil {
+		return m.RevParseVerifyFunc(ref)
+	}
+	return true
+}
 
 // Config Operations
 func (m *mockAddGitClient) ConfigGet(_ string) (string, error)       { return "", nil }
@@ -247,34 +279,34 @@ func TestAdder_Add_RunError_PrintsError(t *testing.T) {
 	}
 }
 
-func TestAdder_Add_POption_CallsGitAddP(t *testing.T) {
+func TestAdder_Add_PatchSubcommand_CallsInteractive(t *testing.T) {
 	mockClient := &mockAddGitClient{}
 	adder := &Adder{
 		gitClient:    mockClient,
 		outputWriter: &bytes.Buffer{},
 	}
-	adder.Add([]string{"-p"})
+	adder.Add([]string{"patch"})
 
 	if !mockClient.addInteractiveCalled {
 		t.Error("AddInteractive was not called")
 	}
 	if mockClient.addCalled {
-		t.Error("Add should not be called for -p option")
+		t.Error("Add should not be called for patch subcommand")
 	}
 }
 
-func TestAdder_Add_POption_Error(t *testing.T) {
+func TestAdder_Add_PatchSubcommand_Error(t *testing.T) {
 	mockClient := &mockAddGitClient{addInteractiveError: errors.New("interactive add failed")}
 	var buf bytes.Buffer
 	adder := &Adder{
 		gitClient:    mockClient,
 		outputWriter: &buf,
 	}
-	adder.Add([]string{"-p"})
+	adder.Add([]string{"patch"})
 
 	output := buf.String()
 	if output == "" || output[:5] != "Error" {
-		t.Errorf("Error output not generated with -p option: %s", output)
+		t.Errorf("Error output not generated with patch subcommand: %s", output)
 	}
 }
 
@@ -286,11 +318,11 @@ func TestAdder_Add_Interactive(t *testing.T) {
 		outputWriter: &buf,
 	}
 
-	adder.Add([]string{"-p"})
+	adder.Add([]string{"patch"})
 
 	// Check that AddInteractive was called
 	if !mockClient.addInteractiveCalled {
-		t.Error("AddInteractive should be called for -p option")
+		t.Error("AddInteractive should be called for patch subcommand")
 	}
 }
 
@@ -364,3 +396,21 @@ func TestAdder_Add_Error(t *testing.T) {
 		t.Errorf("expected error message, got %q", output)
 	}
 }
+
+func TestAdder_Add_InteractiveSubcommand_CallsInteractive(t *testing.T) {
+	mockClient := &mockAddGitClient{}
+	var buf bytes.Buffer
+	adder := &Adder{
+		gitClient:    mockClient,
+		outputWriter: &buf,
+	}
+
+	adder.Add([]string{"interactive"})
+
+	if !mockClient.addInteractiveCalled {
+		t.Error("AddInteractive was not called for 'interactive' subcommand")
+	}
+	if mockClient.addCalled {
+		t.Error("Add should not be called for 'interactive' subcommand")
+	}
+}
