@@ -6,6 +6,7 @@ import (
 	"io"
 	"os"
 	"os/signal"
+	"strings"
 	"syscall"
 
 	"github.com/bmf-san/ggc/v5/git"
@@ -38,7 +39,7 @@ type Executer interface {
 
 // Cmd represents the command-line interface.
 type Cmd struct {
-	gitClient    git.Clienter
+	gitClient    git.StatusInfoReader
 	outputWriter io.Writer
 	helper       *Helper
 	brancher     *Brancher
@@ -49,22 +50,47 @@ type Cmd struct {
 	resetter     *Resetter
 	cleaner      *Cleaner
 	adder        *Adder
-	remoteer     *Remoteer
+	remoter      *Remoter
 	rebaser      *Rebaser
 	stasher      *Stasher
-	configureer  *Configureer
+	configurer   *Configurer
 	hooker       *Hooker
 	tagger       *Tagger
-	statuseer    *Statuseer
-	versioneer   *Versioneer
+	statuser     *Statuser
+	versioner    *Versioner
 	completer    *Completer
 	differ       *Differ
-	restoreer    *Restoreer
+	restorer     *Restorer
 	fetcher      *Fetcher
 }
 
+// GitDeps is a composite for wiring commands that depend on git operations.
+// This narrows each command to the smallest required surface while keeping
+// construction ergonomic.
+type GitDeps interface {
+	git.BranchOps
+	git.CommitWriter
+	git.LogReader
+	git.Puller
+	git.Pusher
+	git.ResetOps
+	git.CleanOps
+	git.Stager
+	git.RemoteManager
+	git.RebaseOps
+	git.StashOps
+	git.ConfigOps
+	git.TagOps
+	git.StatusInfoReader
+	git.DiffReader
+	git.RestoreOps
+	git.FetchOps
+	git.LocalBranchLister
+	git.FileLister
+}
+
 // NewCmd creates a new Cmd with the provided git client.
-func NewCmd(client git.Clienter) *Cmd {
+func NewCmd(client GitDeps) *Cmd {
 	return &Cmd{
 		gitClient:    client,
 		outputWriter: os.Stdout,
@@ -77,21 +103,29 @@ func NewCmd(client git.Clienter) *Cmd {
 		resetter:     NewResetter(client),
 		cleaner:      NewCleaner(client),
 		adder:        NewAdder(client),
-		remoteer:     NewRemoteer(client),
+		remoter:      NewRemoter(client),
 		rebaser:      NewRebaser(client),
 		stasher:      NewStasher(client),
-		configureer:  NewConfigureer(client),
+		configurer:   NewConfigurer(client),
 		hooker:       NewHooker(client),
 		tagger:       NewTagger(client),
-		statuseer:    NewStatuseer(client),
-		versioneer:   NewVersioneer(client),
+		statuser:     NewStatuser(client),
+		versioner:    NewVersioner(client),
 		completer:    NewCompleter(client),
 		differ:       NewDiffer(client),
-		restoreer:    NewRestoreer(client),
+		restorer:     NewRestorer(client),
 		fetcher:      NewFetcher(client),
 	}
 }
 
+// SetDefaultRemote sets the default remote used by tag operations.
+// Passes through to Tagger to avoid repeated config loading.
+func (c *Cmd) SetDefaultRemote(remote string) {
+	if c.tagger != nil && strings.TrimSpace(remote) != "" {
+		c.tagger.defaultRemote = remote
+	}
+}
+
 // Help displays help information.
 func (c *Cmd) Help() {
 	c.helper.ShowHelp()
@@ -104,7 +138,7 @@ func (c *Cmd) Branch(args []string) {
 
 // Remote executes the remote command with the given arguments.
 func (c *Cmd) Remote(args []string) {
-	c.remoteer.Remote(args)
+	c.remoter.Remote(args)
 }
 
 // Rebase executes the rebase command with the given arguments.
@@ -139,12 +173,12 @@ func (c *Cmd) Add(args []string) {
 
 // Status executes the status command with the given arguments.
 func (c *Cmd) Status(args []string) {
-	c.statuseer.Status(args)
+	c.statuser.Status(args)
 }
 
 // Config executes the status command with the given arguments.
 func (c *Cmd) Config(args []string) {
-	c.configureer.Config(args)
+	c.configurer.Config(args)
 }
 
 // Hook executes the hook command with the given arguments.
@@ -164,12 +198,12 @@ func (c *Cmd) Diff(args []string) {
 
 // Restore executes the restore command with the given arguments.
 func (c *Cmd) Restore(args []string) {
-	c.restoreer.Restore(args)
+	c.restorer.Restore(args)
 }
 
 // Version executes the version command with the given arguments.
 func (c *Cmd) Version(args []string) {
-	c.versioneer.Version(args)
+	c.versioner.Version(args)
 }
 
 // Pull executes the pull command with the given arguments.
@@ -231,54 +265,104 @@ func (c *Cmd) Route(args []string) {
 		return
 	}
 
-	switch args[0] {
-	case "help":
-		c.Help()
-	case "add":
-		c.adder.Add(args[1:])
-	case "branch":
-		c.Branch(args[1:])
-	case "commit":
-		c.Commit(args[1:])
-	case "log":
-		c.Log(args[1:])
-	case "pull":
-		c.Pull(args[1:])
-	case "push":
-		c.Push(args[1:])
-	case "reset":
-		c.Reset(args[1:])
-	case "clean":
-		c.Clean(args[1:])
-	case "version":
-		c.Version(args[1:])
-	case "clean-interactive":
-		c.cleaner.CleanInteractive()
-	case "remote":
-		c.remoteer.Remote(args[1:])
-	case "rebase":
-		c.rebaser.Rebase(args[1:])
-	case "stash":
-		c.stasher.Stash(args[1:])
-	case "config":
-		c.configureer.Config(args[1:])
-	case "hook":
-		c.hooker.Hook(args[1:])
-	case "tag":
-		c.tagger.Tag(args[1:])
-	case "status":
-		c.statuseer.Status(args[1:])
-	case "complete":
-		c.completer.Complete(args[1:])
-	case "fetch":
-		c.fetcher.Fetch(args[1:])
-	case "diff":
-		c.differ.Diff(args[1:])
-	case "restore":
-		c.restoreer.Restore(args[1:])
-	default:
-		c.Help()
+	// Treat legacy-like syntax as a hard error (no heuristics/suggestions)
+	if isLegacyLike(args) {
+		_, _ = fmt.Fprintln(c.outputWriter, "Error: legacy-like syntax is not supported.")
+		_, _ = fmt.Fprintln(c.outputWriter, "Use unified subcommands. See: ggc help <command>")
+		return
 	}
+
+	c.routeCommand(args[0], args[1:])
+}
+
+// routeCommand routes to the appropriate command handler
+func (c *Cmd) routeCommand(cmd string, args []string) {
+	// Handle core commands first
+	if c.handleCoreCommand(cmd, args) {
+		return
+	}
+
+	// Handle extended commands
+	c.routeExtendedCommand(cmd, args)
+}
+
+// handleCoreCommand handles core git commands
+func (c *Cmd) handleCoreCommand(cmd string, args []string) bool {
+	coreCommands := map[string]func([]string){
+		"help":    func([]string) { c.Help() },
+		"add":     c.adder.Add,
+		"branch":  c.Branch,
+		"commit":  c.Commit,
+		"log":     c.Log,
+		"pull":    c.Pull,
+		"push":    c.Push,
+		"reset":   c.Reset,
+		"clean":   c.Clean,
+		"version": c.Version,
+	}
+
+	if handler, exists := coreCommands[cmd]; exists {
+		handler(args)
+		return true
+	}
+	return false
+}
+
+// routeExtendedCommand routes to extended command handlers
+func (c *Cmd) routeExtendedCommand(cmd string, args []string) {
+	extendedCommands := map[string]func([]string){
+		"remote":   c.remoter.Remote,
+		"rebase":   c.rebaser.Rebase,
+		"stash":    c.stasher.Stash,
+		"config":   c.configurer.Config,
+		"hook":     c.hooker.Hook,
+		"tag":      c.tagger.Tag,
+		"status":   c.statuser.Status,
+		"complete": c.completer.Complete,
+		"fetch":    c.fetcher.Fetch,
+		"diff":     c.differ.Diff,
+		"restore":  c.restorer.Restore,
+	}
+
+	if handler, exists := extendedCommands[cmd]; exists {
+		handler(args)
+		return
+	}
+	c.Help()
+}
+
+// isLegacyLike reports whether args resemble the pre-v6, flag-driven CLI surface
+// instead of the unified subcommand style introduced in v6.
+// Definition of "legacy-like":
+//   - Hyphenated top-level commands (e.g., "clean-interactive") that used to exist
+//     as separate entry points.
+//   - Flag-style modifiers (e.g., "-i", "--prune") passed to top-level commands to
+//     toggle modes or behaviors.
+//
+// Why this matters: post-v6 the CLI avoids guessing user intent to keep routing
+// predictable, safe, and testable. When legacy-like usage is detected, we fail fast
+// with a clear error to nudge users toward the unified subcommands (see: "ggc help <command>").
+// Detection is intentionally conservative: we flag a hyphen in the top-level command
+// or any leading "-" arguments up to a literal "--" separator; everything after "--"
+// is treated as data.
+func isLegacyLike(args []string) bool {
+	if len(args) == 0 {
+		return false
+	}
+	// Top-level command should never be hyphenated in unified syntax
+	if strings.Contains(args[0], "-") {
+		return true
+	}
+	// Any flag-style argument (starts with '-' or '--') is considered legacy-like
+	for _, a := range args[1:] {
+		if a == "--" { // treat everything after "--" as data
+			break
+		}
+		if strings.HasPrefix(a, "-") {
+			return true
+		}
+	}
+	return false
 }
 
 // waitForContinue waits for user input to continue
