@@ -166,6 +166,10 @@ func (m *mockGitClient) LogOneline(_, _ string) (string, error) { return "", nil
 
 // Rebase Operations methods
 func (m *mockGitClient) RebaseInteractive(_ int) error { return nil }
+func (m *mockGitClient) Rebase(_ string) error         { return nil }
+func (m *mockGitClient) RebaseContinue() error         { return nil }
+func (m *mockGitClient) RebaseAbort() error            { return nil }
+func (m *mockGitClient) RebaseSkip() error             { return nil }
 func (m *mockGitClient) GetUpstreamBranch(_ string) (string, error) {
 	return "origin/main", nil
 }
@@ -202,7 +206,6 @@ func (m *mockGitClient) GetVersion() (string, error)    { return "test-version",
 func (m *mockGitClient) GetCommitHash() (string, error) { return "test-commit", nil }
 
 type mockCmdGitClient struct {
-	git.Clienter
 	pullCalled bool
 	pullRebase bool
 	pushCalled bool
@@ -225,7 +228,7 @@ func TestCmd_Pull(t *testing.T) {
 	mockClient := &mockCmdGitClient{}
 	var buf bytes.Buffer
 	cmd := &Cmd{
-		gitClient:    mockClient,
+		gitClient:    nil,
 		outputWriter: &buf,
 		puller:       NewPuller(mockClient),
 	}
@@ -244,7 +247,7 @@ func TestCmd_Push(t *testing.T) {
 	mockClient := &mockCmdGitClient{}
 	var buf bytes.Buffer
 	cmd := &Cmd{
-		gitClient:    mockClient,
+		gitClient:    nil,
 		outputWriter: &buf,
 		pusher:       NewPusher(mockClient),
 	}
@@ -305,8 +308,8 @@ func TestCmd_Commit(t *testing.T) {
 		wantCalled func(mc *mockGitClient) bool
 	}{
 		{
-			name: "allow-empty",
-			args: []string{"allow-empty"},
+			name: "allow empty",
+			args: []string{"allow", "empty"},
 			wantCalled: func(mc *mockGitClient) bool {
 				return mc.commitAllowEmptyCalled
 			},
@@ -413,7 +416,7 @@ func TestNewCmd(t *testing.T) {
 	if cmd.rebaser == nil {
 		t.Error("rebaser should not be nil")
 	}
-	if cmd.remoteer == nil {
+	if cmd.remoter == nil {
 		t.Error("remoteer should not be nil")
 	}
 	if cmd.resetter == nil {
@@ -462,16 +465,16 @@ func TestCmd_Help(t *testing.T) {
 
 func TestCmd_Branch(t *testing.T) {
 	// Use mock client to avoid git command side effects
-	mockClient := &mockGitClient{}
 	var buf bytes.Buffer
 	helper := NewHelper()
 	helper.outputWriter = &buf
 
 	cmd := &Cmd{
-		gitClient:    mockClient,
+		gitClient:    nil,
 		outputWriter: &buf,
 		helper:       helper,
-		brancher:     &Brancher{gitClient: mockClient, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: &buf, helper: helper},
+		// help path does not access gitClient; pass nil to minimize dependencies
+		brancher: &Brancher{gitClient: nil, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: &buf, helper: helper},
 	}
 
 	cmd.Branch([]string{})
@@ -493,26 +496,26 @@ func TestCmd_Route(t *testing.T) {
 		outputWriter: io.Discard,
 		helper:       helper,
 		// Initialize all components with mock clients to avoid side effects
-		adder:       &Adder{gitClient: mockClient, outputWriter: io.Discard},
-		brancher:    &Brancher{gitClient: mockClient, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: io.Discard, helper: helper},
-		committer:   &Committer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		logger:      &Logger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		puller:      &Puller{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		pusher:      &Pusher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		resetter:    &Resetter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		cleaner:     &Cleaner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		remoteer:    &Remoteer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		rebaser:     &Rebaser{gitClient: mockClient, outputWriter: io.Discard, helper: helper, inputReader: bufio.NewReader(strings.NewReader(""))},
-		stasher:     &Stasher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		configureer: &Configureer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		hooker:      &Hooker{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		tagger:      &Tagger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		statuseer:   &Statuseer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		versioneer:  &Versioneer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		completer:   &Completer{gitClient: mockClient},
-		differ:      &Differ{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		restoreer:   &Restoreer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		fetcher:     &Fetcher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		adder:      &Adder{gitClient: mockClient, outputWriter: io.Discard},
+		brancher:   &Brancher{gitClient: mockClient, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: io.Discard, helper: helper},
+		committer:  &Committer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		logger:     &Logger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		puller:     &Puller{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		pusher:     &Pusher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		resetter:   &Resetter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		cleaner:    &Cleaner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		remoter:    &Remoter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		rebaser:    &Rebaser{gitClient: mockClient, outputWriter: io.Discard, helper: helper, inputReader: bufio.NewReader(strings.NewReader(""))},
+		stasher:    &Stasher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		configurer: &Configurer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		hooker:     &Hooker{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		tagger:     &Tagger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		statuser:   &Statuser{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		versioner:  &Versioner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		completer:  &Completer{gitClient: mockClient},
+		differ:     &Differ{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		restorer:   &Restorer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		fetcher:    &Fetcher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 	}
 
 	testCases := []struct {
@@ -558,6 +561,56 @@ func TestCmd_Route(t *testing.T) {
 	}
 }
 
+func TestCmd_Route_SeparatorAllowsHyphenValues(t *testing.T) {
+	// Use mock client to avoid git command side effects
+	mockClient := &mockGitClient{}
+	helper := NewHelper()
+	helper.outputWriter = io.Discard
+
+	var buf bytes.Buffer
+	cmd := &Cmd{
+		gitClient:    mockClient,
+		outputWriter: &buf, // capture legacy-like error output if any
+		helper:       helper,
+		adder:        &Adder{gitClient: mockClient, outputWriter: io.Discard},
+		brancher:     &Brancher{gitClient: mockClient, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: io.Discard, helper: helper},
+		committer:    &Committer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		logger:       &Logger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		puller:       &Puller{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		pusher:       &Pusher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		resetter:     &Resetter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		cleaner:      &Cleaner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		remoter:      &Remoter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		rebaser:      &Rebaser{gitClient: mockClient, outputWriter: io.Discard, helper: helper, inputReader: bufio.NewReader(strings.NewReader(""))},
+		stasher:      &Stasher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		configurer:   &Configurer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		hooker:       &Hooker{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		tagger:       &Tagger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		statuser:     &Statuser{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		versioner:    &Versioner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		completer:    &Completer{gitClient: mockClient},
+		differ:       &Differ{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		restorer:     &Restorer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		fetcher:      &Fetcher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+	}
+
+	// Using "--" should allow a value starting with '-' to pass through
+	// without triggering the legacy-like error.
+	args := []string{"commit", "--", "-leading dash message"}
+
+	defer func() {
+		if r := recover(); r != nil {
+			t.Errorf("Route() should not panic for args %v, but got: %v", args, r)
+		}
+	}()
+
+	cmd.Route(args)
+
+	if strings.Contains(buf.String(), "legacy-like syntax is not supported") {
+		t.Fatalf("did not expect legacy-like error when using '--' separator, got: %q", buf.String())
+	}
+}
+
 // Test some behavior of Interactive by mocking InteractiveUI
 func TestCmd_Interactive_Existence(t *testing.T) {
 	// Interactive is a complex interactive function, making complete testing difficult
@@ -584,10 +637,10 @@ func TestCmd_Status(t *testing.T) {
 	cmd := &Cmd{
 		outputWriter: io.Discard,
 		gitClient:    mockClient,
-		statuseer:    &Statuseer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		statuser:     &Statuser{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 	}
 
-	// Test that Status calls the statuseer
+	// Test that Status calls the statuser
 	defer func() {
 		if r := recover(); r != nil {
 			t.Errorf("Status should not panic, got: %v", r)
@@ -605,10 +658,10 @@ func TestCmd_Config(t *testing.T) {
 	cmd := &Cmd{
 		outputWriter: io.Discard,
 		gitClient:    mockClient,
-		configureer:  &Configureer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		configurer:   &Configurer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 	}
 
-	// Test that Config calls the configureer
+	// Test that Config calls the configurer
 	defer func() {
 		if r := recover(); r != nil {
 			t.Errorf("Config should not panic, got: %v", r)
@@ -689,10 +742,10 @@ func TestCmd_Restore(t *testing.T) {
 	cmd := &Cmd{
 		outputWriter: io.Discard,
 		gitClient:    mockClient,
-		restoreer:    &Restoreer{outputWriter: io.Discard, helper: helper},
+		restorer:     &Restorer{outputWriter: io.Discard, helper: helper},
 	}
 
-	// Test that Restore calls the restoreer
+	// Test that Restore calls the restorer
 	defer func() {
 		if r := recover(); r != nil {
 			t.Errorf("Restore should not panic, got: %v", r)
@@ -715,10 +768,10 @@ func TestCmd_Version(t *testing.T) {
 	cmd := &Cmd{
 		outputWriter: io.Discard,
 		gitClient:    mockClient,
-		versioneer:   &Versioneer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
+		versioner:    &Versioner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 	}
 
-	// Test that Version calls the versioneer
+	// Test that Version calls the versioner
 	defer func() {
 		if r := recover(); r != nil {
 			t.Errorf("Version should not panic, got: %v", r)
