@@ -9,11 +9,18 @@ import (
 
 // Completer handles dynamic completion for subcommands/args
 type Completer struct {
-	gitClient git.Clienter
+	// Needs only local branches and file listing for completion
+	gitClient interface {
+		git.LocalBranchLister
+		git.FileLister
+	}
 }
 
 // NewCompleter creates a new Completer.
-var NewCompleter = func(client git.Clienter) *Completer {
+var NewCompleter = func(client interface {
+	git.LocalBranchLister
+	git.FileLister
+}) *Completer {
 	return &Completer{
 		gitClient: client,
 	}
@@ -31,17 +38,16 @@ func (c *Completer) Complete(args []string) {
 			subs := []string{
 				"current",
 				"checkout",
-				"checkout-remote",
 				"create",
 				"delete",
-				"delete-merged",
+				// follow-ups: 'delete merged'
 				// Enhanced branch management
 				"rename",
 				"move",
-				"set-upstream",
+				// follow-ups: 'set upstream'
 				"info",
 				"list",
-				"list --verbose",
+				// follow-ups: 'list verbose'
 				"sort",
 				"contains",
 			}
@@ -59,16 +65,19 @@ func (c *Completer) Complete(args []string) {
 			fmt.Println(b)
 		}
 	case "files":
-		// Get list of files managed by git ls-files
-		out, err := c.gitClient.ListFiles()
-		if err != nil {
-			return
-		}
-		files := strings.Split(strings.TrimSpace(out), "\n")
-		for _, f := range files {
-			fmt.Println(f)
-		}
+		c.completeFiles()
 	default:
 		// Other completions can be added in the future
 	}
 }
+
+func (c *Completer) completeFiles() {
+	out, err := c.gitClient.ListFiles()
+	if err != nil {
+		return
+	}
+	files := strings.Split(strings.TrimSpace(out), "\n")
+	for _, f := range files {
+		fmt.Println(f)
+	}
+}
