@@ -10,13 +10,13 @@ import (
 
 // Fetcher handles git fetch operations.
 type Fetcher struct {
-	gitClient    git.Clienter
+	gitClient    git.FetchOps
 	outputWriter io.Writer
 	helper       *Helper
 }
 
 // NewFetcher creates a new Fetcher instance.
-func NewFetcher(client git.Clienter) *Fetcher {
+func NewFetcher(client git.FetchOps) *Fetcher {
 	return &Fetcher{
 		gitClient:    client,
 		outputWriter: os.Stdout,
@@ -32,7 +32,7 @@ func (f *Fetcher) Fetch(args []string) {
 	}
 
 	switch args[0] {
-	case "--prune":
+	case "prune":
 		if err := f.gitClient.Fetch(true); err != nil {
 			_, _ = fmt.Fprintf(f.outputWriter, "Error: %v\n", err)
 		}
