@@ -3,16 +3,26 @@ package cmd
 
 import (
 	"bufio"
+	"errors"
 	"fmt"
 	"io"
 	"os"
 	"strconv"
 	"strings"
+	"unicode"
+	"unicode/utf8"
+
+	"golang.org/x/term"
+	"golang.org/x/text/width"
 
 	"github.com/bmf-san/ggc/v5/git"
-	"golang.org/x/term"
 )
 
+// initialInputCapacity defines the initial capacity for the input rune buffer
+// used by the real-time editor. It helps minimize reallocations during typing
+// while keeping memory usage modest.
+const initialInputCapacity = 64
+
 // GitStatus represents the current Git repository status
 type GitStatus struct {
 	Branch     string
@@ -84,7 +94,7 @@ func NewANSIColors() *ANSIColors {
 }
 
 // getGitStatus retrieves the current Git repository status
-func getGitStatus(gitClient git.Clienter) *GitStatus {
+func getGitStatus(gitClient git.StatusInfoReader) *GitStatus {
 	status := &GitStatus{}
 
 	// Get current branch name
@@ -109,7 +119,7 @@ func getGitStatus(gitClient git.Clienter) *GitStatus {
 }
 
 // getGitBranch gets the current branch name
-func getGitBranch(gitClient git.Clienter) string {
+func getGitBranch(gitClient git.StatusInfoReader) string {
 	branch, err := gitClient.GetCurrentBranch()
 	if err != nil {
 		return ""
@@ -118,8 +128,8 @@ func getGitBranch(gitClient git.Clienter) string {
 }
 
 // getGitWorkingStatus gets the number of modified and staged files
-func getGitWorkingStatus(gitClient git.Clienter) (modified, staged int) {
-	output, err := gitClient.GetGitStatus()
+func getGitWorkingStatus(gitClient git.StatusInfoReader) (modified, staged int) {
+	output, err := gitClient.StatusShortWithColor()
 	if err != nil {
 		return 0, 0
 	}
@@ -143,7 +153,7 @@ func getGitWorkingStatus(gitClient git.Clienter) (modified, staged int) {
 }
 
 // getGitRemoteStatus gets ahead/behind count compared to remote
-func getGitRemoteStatus(gitClient git.Clienter) (ahead, behind int) {
+func getGitRemoteStatus(gitClient git.StatusInfoReader) (ahead, behind int) {
 	output, err := gitClient.GetAheadBehindCount("HEAD", "@{upstream}")
 	if err != nil {
 		return 0, 0 // No upstream or other error
@@ -176,7 +186,8 @@ type UI struct {
 	handler   *KeyHandler
 	colors    *ANSIColors
 	gitStatus *GitStatus
-	gitClient git.Clienter
+	gitClient git.StatusInfoReader
+	reader    *bufio.Reader
 }
 
 // UIState holds the current state of the interactive UI
@@ -243,10 +254,18 @@ func (s *UIState) MoveDown() {
 	}
 }
 
-// AddChar adds a character to the input at cursor position
-func (s *UIState) AddChar(c byte) {
-	if s.cursorPos <= len(s.input) {
-		s.input = s.input[:s.cursorPos] + string(c) + s.input[s.cursorPos:]
+// AddRune adds a UTF-8 rune to the input at cursor position
+func (s *UIState) AddRune(r rune) {
+	// Convert current input to runes for proper cursor positioning
+	inputRunes := []rune(s.input)
+	if s.cursorPos <= len(inputRunes) {
+		// Efficiently insert the rune at the cursor position
+		newRunes := make([]rune, len(inputRunes)+1)
+		copy(newRunes, inputRunes[:s.cursorPos])
+		newRunes[s.cursorPos] = r
+		copy(newRunes[s.cursorPos+1:], inputRunes[s.cursorPos:])
+
+		s.input = string(newRunes)
 		s.cursorPos++
 		s.UpdateFiltered()
 	}
@@ -254,10 +273,16 @@ func (s *UIState) AddChar(c byte) {
 
 // RemoveChar removes character before cursor (backspace)
 func (s *UIState) RemoveChar() {
-	if s.cursorPos > 0 && len(s.input) > 0 {
-		s.input = s.input[:s.cursorPos-1] + s.input[s.cursorPos:]
-		s.cursorPos--
-		s.UpdateFiltered()
+	if s.cursorPos > 0 && s.input != "" {
+		// Convert to runes for proper UTF-8 handling
+		inputRunes := []rune(s.input)
+		if s.cursorPos <= len(inputRunes) {
+			inputRunes = append(inputRunes[:s.cursorPos-1], inputRunes[s.cursorPos:]...)
+
+			s.input = string(inputRunes)
+			s.cursorPos--
+			s.UpdateFiltered()
+		}
 	}
 }
 
@@ -274,28 +299,33 @@ func (s *UIState) DeleteWord() {
 		return
 	}
 
+	// Convert to runes for proper UTF-8 handling
+	inputRunes := []rune(s.input)
+
 	// Find start of current word (skip trailing spaces first)
 	pos := s.cursorPos - 1
-	for pos >= 0 && s.input[pos] == ' ' {
+	for pos >= 0 && inputRunes[pos] == ' ' {
 		pos--
 	}
 
 	// Find start of word
-	for pos >= 0 && s.input[pos] != ' ' {
+	for pos >= 0 && inputRunes[pos] != ' ' {
 		pos--
 	}
 	pos++ // Move to first character of word
 
 	// Delete from word start to cursor
-	s.input = s.input[:pos] + s.input[s.cursorPos:]
+	inputRunes = append(inputRunes[:pos], inputRunes[s.cursorPos:]...)
+	s.input = string(inputRunes)
 	s.cursorPos = pos
 	s.UpdateFiltered()
 }
 
 // DeleteToEnd deletes from cursor to end of line (Ctrl+K)
 func (s *UIState) DeleteToEnd() {
-	if s.cursorPos < len(s.input) {
-		s.input = s.input[:s.cursorPos]
+	if s.cursorPos < utf8.RuneCountInString(s.input) {
+		inputRunes := []rune(s.input)
+		s.input = string(inputRunes[:s.cursorPos])
 		s.UpdateFiltered()
 	}
 }
@@ -307,7 +337,58 @@ func (s *UIState) MoveToBeginning() {
 
 // MoveToEnd moves cursor to end of line (Ctrl+E)
 func (s *UIState) MoveToEnd() {
-	s.cursorPos = len(s.input)
+	s.cursorPos = utf8.RuneCountInString(s.input)
+}
+
+// MoveLeft moves cursor one rune left
+func (s *UIState) MoveLeft() {
+	if s.cursorPos > 0 {
+		s.cursorPos--
+	}
+}
+
+// MoveRight moves cursor one rune right
+func (s *UIState) MoveRight() {
+	if s.cursorPos < utf8.RuneCountInString(s.input) {
+		s.cursorPos++
+	}
+}
+
+// MoveWordLeft moves cursor to the beginning of the previous word
+func (s *UIState) MoveWordLeft() {
+	if s.cursorPos == 0 {
+		return
+	}
+	runes := []rune(s.input)
+	pos := s.cursorPos - 1
+	// Skip any spaces to the left
+	for pos >= 0 && unicode.IsSpace(runes[pos]) {
+		pos--
+	}
+	// Skip the word characters to the left
+	for pos >= 0 && !unicode.IsSpace(runes[pos]) {
+		pos--
+	}
+	s.cursorPos = pos + 1
+}
+
+// MoveWordRight moves cursor to the start of the next word
+func (s *UIState) MoveWordRight() {
+	runes := []rune(s.input)
+	n := len(runes)
+	pos := s.cursorPos
+	if pos >= n {
+		return
+	}
+	// Skip current word characters
+	for pos < n && !unicode.IsSpace(runes[pos]) {
+		pos++
+	}
+	// Skip following spaces
+	for pos < n && unicode.IsSpace(runes[pos]) {
+		pos++
+	}
+	s.cursorPos = pos
 }
 
 // GetSelectedCommand returns the currently selected command
@@ -341,43 +422,150 @@ type KeyHandler struct {
 	ui *UI
 }
 
-// HandleKey processes a single key input and returns true if should continue
-func (h *KeyHandler) HandleKey(b byte, oldState *term.State) (bool, []string) {
+// HandleKey processes UTF-8 rune input and returns true if should continue
+// This method handles both single-byte (ASCII/control) and multibyte characters
+func (h *KeyHandler) HandleKey(r rune, isSingleByte bool, oldState *term.State) (bool, []string) {
+	// Handle control characters (single-byte)
+	if isSingleByte {
+		if handled, shouldContinue, result := h.handleControlChar(byte(r), oldState); handled {
+			return shouldContinue, result
+		}
+	}
+
+	// Handle printable characters (both ASCII and multibyte)
+	if unicode.IsPrint(r) {
+		h.ui.state.AddRune(r)
+	}
+	return true, nil
+}
+
+// handleControlChar processes control characters and returns (handled, shouldContinue, result)
+//
+//nolint:revive // Control character handling inherently requires many cases
+func (h *KeyHandler) handleControlChar(b byte, oldState *term.State) (bool, bool, []string) {
 	switch b {
 	case 3: // Ctrl+C
 		h.handleCtrlC(oldState)
-		return false, nil
+		return true, false, nil
 	case 13: // Enter
-		return h.handleEnter(oldState)
+		shouldContinue, result := h.handleEnter(oldState)
+		return true, shouldContinue, result
 	case 16: // Ctrl+P (up)
 		h.ui.state.MoveUp()
-		return true, nil
+		return true, true, nil
 	case 14: // Ctrl+N (down)
 		h.ui.state.MoveDown()
-		return true, nil
+		return true, true, nil
 	case 21: // Ctrl+U (clear line)
 		h.ui.state.ClearInput()
-		return true, nil
+		return true, true, nil
 	case 23: // Ctrl+W (delete word)
 		h.ui.state.DeleteWord()
-		return true, nil
+		return true, true, nil
 	case 11: // Ctrl+K (delete to end)
 		h.ui.state.DeleteToEnd()
-		return true, nil
+		return true, true, nil
 	case 1: // Ctrl+A (beginning of line)
 		h.ui.state.MoveToBeginning()
-		return true, nil
+		return true, true, nil
 	case 5: // Ctrl+E (end of line)
 		h.ui.state.MoveToEnd()
-		return true, nil
+		return true, true, nil
 	case 127, 8: // Backspace
 		h.ui.state.RemoveChar()
-		return true, nil
+		return true, true, nil
+	case 27: // ESC: arrow keys and Option/Alt modifiers
+		h.handleEscapeSequence()
+		return true, true, nil
 	default:
-		if b >= 32 && b <= 126 { // Printable ASCII
-			h.ui.state.AddChar(b)
+		return false, true, nil
+	}
+}
+
+// handleEscapeSequence parses common ESC sequences for arrow and word navigation.
+// Supports:
+// - Arrow keys: ESC [ C/D (right/left), ESC O C/D (application mode)
+// - Ctrl+Arrow: ESC [ 1;5 C/D or ESC [ 5 C/D
+// - Alt/Option+Arrow: ESC [ 1;3 C/D, ESC [ 1;9 C/D (varies by terminal)
+// - macOS Option word nav: ESC b / ESC f
+func (h *KeyHandler) handleEscapeSequence() {
+	if h.ui == nil || h.ui.reader == nil {
+		return
+	}
+
+	r := h.ui.reader
+	b, err := r.ReadByte()
+	if err != nil {
+		return
+	}
+
+	switch b {
+	case '[':
+		h.handleCSISequence(r)
+	case 'O':
+		h.handleApplicationCursorMode(r)
+	case 'b':
+		h.ui.state.MoveWordLeft()
+	case 'f':
+		h.ui.state.MoveWordRight()
+	case 127, 8:
+		// Meta-Backspace (Option+Backspace): delete word left
+		h.ui.state.DeleteWord()
+	}
+}
+
+// handleCSISequence handles CSI (Control Sequence Introducer) sequences
+func (h *KeyHandler) handleCSISequence(r *bufio.Reader) {
+	var params []byte
+	for {
+		nb, err := r.ReadByte()
+		if err != nil {
+			return
 		}
-		return true, nil
+		if (nb >= 'A' && nb <= 'Z') || nb == '~' {
+			h.processCSIFinalByte(nb, string(params))
+			return
+		}
+		params = append(params, nb)
+	}
+}
+
+// isWordMotionParam reports whether CSI params include a word-motion modifier
+// commonly emitted by terminals (e.g., Ctrl/Alt variants use 5/3/9).
+func isWordMotionParam(params string) bool {
+	return strings.Contains(params, "5") || strings.Contains(params, "3") || strings.Contains(params, "9")
+}
+
+// processCSIFinalByte processes the final byte of a CSI sequence
+func (h *KeyHandler) processCSIFinalByte(final byte, params string) {
+	isWord := isWordMotionParam(params)
+	switch final {
+	case 'C': // Right
+		if isWord {
+			h.ui.state.MoveWordRight()
+		} else {
+			h.ui.state.MoveRight()
+		}
+	case 'D': // Left
+		if isWord {
+			h.ui.state.MoveWordLeft()
+		} else {
+			h.ui.state.MoveLeft()
+		}
+	}
+}
+
+// handleApplicationCursorMode handles application cursor mode sequences
+func (h *KeyHandler) handleApplicationCursorMode(r *bufio.Reader) {
+	nb, err := r.ReadByte()
+	if err != nil {
+		return
+	}
+	switch nb {
+	case 'C':
+		h.ui.state.MoveRight()
+	case 'D':
+		h.ui.state.MoveLeft()
 	}
 }
 
@@ -478,8 +666,8 @@ func (h *KeyHandler) interactiveInput(placeholders []string) map[string]string {
 		// Get input with real-time feedback
 		value := h.getRealTimeInput(ph)
 		if value == "" {
-			// User cancelled input
-			h.ui.write("\n%sOperation cancelled%s\n",
+			// User canceled input
+			h.ui.write("\n%sOperation canceled%s\n",
 				h.ui.colors.BrightRed,
 				h.ui.colors.Reset)
 			os.Exit(1)
@@ -501,72 +689,490 @@ func (h *KeyHandler) interactiveInput(placeholders []string) map[string]string {
 
 // getRealTimeInput gets user input with real-time display using raw terminal mode
 func (h *KeyHandler) getRealTimeInput(_ string) string {
-	var input strings.Builder
-
-	// Set terminal to raw mode for character-by-character input
 	fd := int(os.Stdin.Fd())
 	oldState, err := h.ui.term.makeRaw(fd)
 	if err != nil {
-		// Fallback to line-based input if raw mode fails
 		return h.getLineInput()
 	}
-	defer func() {
-		_ = h.ui.term.restore(fd, oldState)
-	}()
+	defer func() { _ = h.ui.term.restore(fd, oldState) }()
 
-	// Buffer for reading single bytes
-	buf := make([]byte, 1)
+	return h.processRealTimeInput()
+}
 
-	for {
-		// Read one byte at a time
-		n, err := os.Stdin.Read(buf)
-		if err != nil || n == 0 {
-			break
-		}
+// processRealTimeInput handles the main input processing loop
+func (h *KeyHandler) processRealTimeInput() string {
+	reader := bufio.NewReader(os.Stdin)
+	inputRunes := make([]rune, 0, initialInputCapacity)
+	cursor := 0
 
-		char := rune(buf[0])
-
-		switch char {
-		case '\n', '\r':
-			// Enter pressed - confirm input
-			if input.Len() > 0 {
-				h.ui.write("\r\n")
-				return input.String()
-			}
-			// Empty input - show hint and continue
-			h.ui.write(" %s(required)%s",
-				h.ui.colors.BrightRed,
-				h.ui.colors.Reset)
-			continue
-
-		case '\b', 127: // Backspace
-			if input.Len() > 0 {
-				// Remove last character
-				str := input.String()
-				input.Reset()
-				input.WriteString(str[:len(str)-1])
-
-				// Update display: move back, write space, move back again
-				h.ui.write("\b \b")
-			}
-
-		case 3: // Ctrl+C
-			h.ui.write("\r\n%sOperation cancelled%s\r\n",
-				h.ui.colors.BrightRed,
-				h.ui.colors.Reset)
-			// Return empty string to indicate cancellation
-			return ""
-
-		default:
-			// Regular character
-			if char >= 32 && char <= 126 { // Printable ASCII
-				input.WriteRune(char)
-				h.ui.write("%c", char)
-			}
-		}
+	editor := &realTimeEditor{
+		ui:         h.ui,
+		inputRunes: &inputRunes,
+		cursor:     &cursor,
 	}
 
-	return input.String()
+	for {
+		r, _, err := reader.ReadRune()
+		if errors.Is(err, io.EOF) {
+			break
+		}
+		if err != nil {
+			continue
+		}
+
+		result := editor.handleInput(r, reader)
+		if result.done {
+			return result.text
+		}
+		if result.canceled {
+			return ""
+		}
+	}
+	return string(inputRunes)
+}
+
+// inputResult represents the result of handling input
+type inputResult struct {
+	done     bool
+	canceled bool
+	text     string
+}
+
+// realTimeEditor handles real-time input editing
+type realTimeEditor struct {
+	ui         *UI
+	inputRunes *[]rune
+	cursor     *int
+}
+
+// handleInput processes a single input rune
+func (e *realTimeEditor) handleInput(r rune, reader *bufio.Reader) inputResult {
+	switch r {
+	case '\n', '\r':
+		return e.handleEnter()
+	case 3: // Ctrl+C
+		return e.handleCtrlC()
+	case 127, '\b': // Backspace
+		e.handleBackspace()
+		return inputResult{}
+	case 27: // ESC sequences
+		e.handleEscape(reader)
+		return inputResult{}
+	default:
+		if unicode.IsPrint(r) {
+			e.handlePrintableChar(r)
+		}
+		return inputResult{}
+	}
+}
+
+// handleEnter processes Enter key
+func (e *realTimeEditor) handleEnter() inputResult {
+	if len(*e.inputRunes) > 0 {
+		e.ui.write("\r\n")
+		return inputResult{done: true, text: string(*e.inputRunes)}
+	}
+	e.ui.write(" %s(required)%s", e.ui.colors.BrightRed, e.ui.colors.Reset)
+	return inputResult{}
+}
+
+// handleCtrlC processes Ctrl+C
+func (e *realTimeEditor) handleCtrlC() inputResult {
+	e.ui.write("\r\n%sOperation canceled%s\r\n", e.ui.colors.BrightRed, e.ui.colors.Reset)
+	return inputResult{canceled: true}
+}
+
+// handleBackspace processes backspace key
+func (e *realTimeEditor) handleBackspace() {
+	if *e.cursor == 0 {
+		return
+	}
+	start := e.findGraphemeStart(*e.cursor - 1)
+	// Compute columns to move left/clear for the removed cluster
+	moveCols := e.colsBetween(start, *e.cursor)
+	clearedCols := 0
+	for i := start; i < *e.cursor; i++ {
+		clearedCols += e.runeWidth((*e.inputRunes)[i])
+	}
+	// Move cursor left, remove runes, and redraw tail
+	e.moveLeft(moveCols)
+	*e.inputRunes = append((*e.inputRunes)[:start], (*e.inputRunes)[*e.cursor:]...)
+	*e.cursor = start
+	e.printTailAndReposition(*e.cursor, clearedCols)
+}
+
+// findGraphemeStart finds the start of the grapheme cluster ending at the given position
+func (e *realTimeEditor) findGraphemeStart(pos int) int {
+	start := pos
+	start = e.skipCombiningMarks(start)
+	start = e.handleRegionalIndicators(start)
+	start = e.handleZWJSequences(start)
+	if start < 0 {
+		start = 0
+	}
+	return start
+}
+
+// skipCombiningMarks skips any trailing variation selectors or combining marks
+func (e *realTimeEditor) skipCombiningMarks(start int) int {
+	for start >= 0 && (isCombining((*e.inputRunes)[start]) || isVariationSelector((*e.inputRunes)[start])) {
+		start--
+	}
+	return start
+}
+
+// handleRegionalIndicators handles regional indicator pairs (flags)
+func (e *realTimeEditor) handleRegionalIndicators(start int) int {
+	if start >= 0 && isRegionalIndicator((*e.inputRunes)[start]) {
+		if start > 0 && isRegionalIndicator((*e.inputRunes)[start-1]) {
+			start--
+		}
+	}
+	return start
+}
+
+// handleZWJSequences handles ZWJ sequences by including the joiner and previous rune repeatedly
+func (e *realTimeEditor) handleZWJSequences(start int) int {
+	for {
+		if start > 0 && isZWJ((*e.inputRunes)[start-1]) {
+			// Include ZWJ and the previous rune
+			start -= 2
+			// Also include any combining marks attached to the new base
+			start = e.skipCombiningMarks(start)
+			continue
+		}
+		break
+	}
+	return start
+}
+
+// handlePrintableChar processes printable characters
+func (e *realTimeEditor) handlePrintableChar(r rune) {
+	if *e.cursor == len(*e.inputRunes) {
+		*e.inputRunes = append(*e.inputRunes, r)
+	} else {
+		*e.inputRunes = append((*e.inputRunes)[:*e.cursor], append([]rune{r}, (*e.inputRunes)[*e.cursor:]...)...)
+	}
+	e.ui.write("%s", string(r))
+	*e.cursor++
+	e.printTailAndReposition(*e.cursor, 0)
+}
+
+// handleEscape processes escape sequences for real-time input
+func (e *realTimeEditor) handleEscape(reader *bufio.Reader) {
+	b, err := reader.ReadByte()
+	if err != nil {
+		return
+	}
+	switch b {
+	case '[':
+		e.handleCSIEscape(reader)
+	case 'O':
+		e.handleApplicationEscape(reader)
+	case 'b':
+		e.moveWordLeft()
+	case 'f':
+		e.moveWordRight()
+	case 127, '\b':
+		// Option+Backspace: delete previous word
+		e.deleteWordLeft()
+	}
+}
+
+// handleCSIEscape processes CSI escape sequences for real-time input
+func (e *realTimeEditor) handleCSIEscape(reader *bufio.Reader) {
+	var params []byte
+	for {
+		nb, err := reader.ReadByte()
+		if err != nil {
+			return
+		}
+		if (nb >= 'A' && nb <= 'Z') || nb == '~' {
+			e.processCSIEscape(nb, string(params))
+			return
+		}
+		params = append(params, nb)
+	}
+}
+
+// processCSIEscape handles CSI final byte for real-time input
+func (e *realTimeEditor) processCSIEscape(final byte, params string) {
+	isWord := isWordMotionParam(params)
+	switch final {
+	case 'C': // Right
+		if isWord {
+			e.moveWordRight()
+		} else if *e.cursor < len(*e.inputRunes) {
+			e.moveRight(e.runeWidth((*e.inputRunes)[*e.cursor]))
+			*e.cursor++
+		}
+	case 'D': // Left
+		if isWord {
+			e.moveWordLeft()
+		} else if *e.cursor > 0 {
+			e.moveLeft(e.runeWidth((*e.inputRunes)[*e.cursor-1]))
+			*e.cursor--
+		}
+	}
+}
+
+// handleApplicationEscape processes application mode escape sequences
+func (e *realTimeEditor) handleApplicationEscape(reader *bufio.Reader) {
+	nb, err := reader.ReadByte()
+	if err != nil {
+		return
+	}
+	switch nb {
+	case 'C':
+		if *e.cursor < len(*e.inputRunes) {
+			e.moveRight(e.runeWidth((*e.inputRunes)[*e.cursor]))
+			*e.cursor++
+		}
+	case 'D':
+		if *e.cursor > 0 {
+			e.moveLeft(e.runeWidth((*e.inputRunes)[*e.cursor-1]))
+			*e.cursor--
+		}
+	}
+}
+
+// Helper methods for realTimeEditor
+
+// isCombining reports whether r is a combining mark (zero display width)
+func isCombining(r rune) bool {
+	return unicode.Is(unicode.Mn, r) || unicode.Is(unicode.Me, r) || unicode.Is(unicode.Mc, r)
+}
+
+// isVariationSelector reports whether r is a variation selector (zero width)
+func isVariationSelector(r rune) bool {
+	// U+FE00..U+FE0F (VS1..VS16) and U+E0100..U+E01EF (IVS)
+	return (r >= 0xFE00 && r <= 0xFE0F) || (r >= 0xE0100 && r <= 0xE01EF)
+}
+
+// isRegionalIndicator reports whether r is a regional indicator rune (used for flags)
+func isRegionalIndicator(r rune) bool { return r >= 0x1F1E6 && r <= 0x1F1FF }
+
+// isZWJ reports whether r is ZERO WIDTH JOINER
+func isZWJ(r rune) bool { return r == 0x200D }
+
+// isEmoji reports common emoji ranges that should render as width 2 on most terminals
+func isEmoji(r rune) bool {
+	return isEmojiRange1(r) || isEmojiRange2(r)
+}
+
+// isEmojiRange1 checks the first set of emoji Unicode ranges
+func isEmojiRange1(r rune) bool {
+	return (r >= 0x1F300 && r <= 0x1F5FF) || // Misc Symbols and Pictographs
+		(r >= 0x1F600 && r <= 0x1F64F) || // Emoticons
+		(r >= 0x1F680 && r <= 0x1F6FF) || // Transport and Map Symbols
+		(r >= 0x1F700 && r <= 0x1F77F) || // Alchemical Symbols
+		(r >= 0x1F780 && r <= 0x1F7FF) // Geometric Shapes Extended
+}
+
+// isEmojiRange2 checks the second set of emoji Unicode ranges
+func isEmojiRange2(r rune) bool {
+	return (r >= 0x1F800 && r <= 0x1F8FF) || // Supplemental Arrows-C
+		(r >= 0x1F900 && r <= 0x1F9FF) || // Supplemental Symbols and Pictographs
+		(r >= 0x1FA00 && r <= 0x1FAFF) || // Symbols and Pictographs Extended-A
+		(r >= 0x2600 && r <= 0x26FF) || // Misc symbols
+		(r >= 0x2700 && r <= 0x27BF) // Dingbats
+}
+
+// runeDisplayWidth returns the number of terminal columns used by r
+func runeDisplayWidth(r rune) int {
+	// Zero-width characters
+	if isCombining(r) || isVariationSelector(r) || isZWJ(r) {
+		return 0
+	}
+	// East Asian wide/fullwidth
+	switch width.LookupRune(r).Kind() {
+	case width.EastAsianFullwidth, width.EastAsianWide:
+		return 2
+	}
+	// Common emoji are typically 2 columns
+	if isEmoji(r) {
+		return 2
+	}
+	return 1
+}
+
+func (e *realTimeEditor) runeWidth(r rune) int { return runeDisplayWidth(r) }
+
+func (e *realTimeEditor) colsBetween(from, to int) int {
+	if from < 0 {
+		from = 0
+	}
+	if to < 0 {
+		to = 0
+	}
+	if from > to {
+		from, to = to, from
+	}
+	cols := 0
+	for i := from; i < to && i < len(*e.inputRunes); i++ {
+		cols += e.runeWidth((*e.inputRunes)[i])
+	}
+	return cols
+}
+
+func (e *realTimeEditor) moveLeft(cols int) {
+	if cols <= 0 {
+		return
+	}
+	e.ui.write("\x1b[%dD", cols)
+}
+
+func (e *realTimeEditor) moveRight(cols int) {
+	if cols <= 0 {
+		return
+	}
+	e.ui.write("\x1b[%dC", cols)
+}
+
+func (e *realTimeEditor) printTailAndReposition(from int, clearedCols int) {
+	tailCols := 0
+	if from < len(*e.inputRunes) {
+		tail := string((*e.inputRunes)[from:])
+		e.ui.write("%s", tail)
+		for _, rr := range (*e.inputRunes)[from:] {
+			tailCols += e.runeWidth(rr)
+		}
+	}
+	if clearedCols > 0 {
+		e.ui.write("%s", strings.Repeat(" ", clearedCols))
+	}
+	e.moveLeft(tailCols + clearedCols)
+}
+
+func (e *realTimeEditor) moveWordLeft() {
+	if *e.cursor == 0 {
+		return
+	}
+	i := *e.cursor - 1
+	for i >= 0 && unicode.IsSpace((*e.inputRunes)[i]) {
+		i--
+	}
+	for i >= 0 && !unicode.IsSpace((*e.inputRunes)[i]) {
+		i--
+	}
+	newPos := i + 1
+	delta := e.colsBetween(newPos, *e.cursor)
+	e.moveLeft(delta)
+	*e.cursor = newPos
+}
+
+func (e *realTimeEditor) moveWordRight() {
+	n := len(*e.inputRunes)
+	if *e.cursor >= n {
+		return
+	}
+	i := *e.cursor
+	for i < n && !unicode.IsSpace((*e.inputRunes)[i]) {
+		i++
+	}
+	for i < n && unicode.IsSpace((*e.inputRunes)[i]) {
+		i++
+	}
+	delta := e.colsBetween(*e.cursor, i)
+	e.moveRight(delta)
+	*e.cursor = i
+}
+
+// deleteWordLeft deletes the word before the cursor and updates the display
+func (e *realTimeEditor) deleteWordLeft() {
+	if *e.cursor == 0 {
+		return
+	}
+	// Find new cursor position at the beginning of previous word
+	i := *e.cursor - 1
+	for i >= 0 && unicode.IsSpace((*e.inputRunes)[i]) {
+		i--
+	}
+	for i >= 0 && !unicode.IsSpace((*e.inputRunes)[i]) {
+		i--
+	}
+	newPos := i + 1
+	// Compute columns to move left and columns to clear
+	moveCols := e.colsBetween(newPos, *e.cursor)
+	clearedCols := 0
+	for j := newPos; j < *e.cursor; j++ {
+		clearedCols += e.runeWidth((*e.inputRunes)[j])
+	}
+	// Move cursor left to newPos
+	e.moveLeft(moveCols)
+	// Delete runes in [newPos, cursor)
+	*e.inputRunes = append((*e.inputRunes)[:newPos], (*e.inputRunes)[*e.cursor:]...)
+	*e.cursor = newPos
+	// Redraw tail and clear leftover cells
+	e.printTailAndReposition(*e.cursor, clearedCols)
+}
+
+//nolint:revive // Input character handling inherently requires multiple cases
+func (h *KeyHandler) handleInputChar(input *strings.Builder, char rune) (done bool, canceled bool) {
+	switch char {
+	case '\n', '\r':
+		if input.Len() > 0 {
+			h.ui.write("\r\n")
+			return true, false
+		}
+		h.ui.write(" %s(required)%s", h.ui.colors.BrightRed, h.ui.colors.Reset)
+		return false, false
+	case '\b', 127:
+		if input.Len() == 0 {
+			return false, false
+		}
+		runes := []rune(input.String())
+		if len(runes) == 0 {
+			return false, false
+		}
+		// Identify start of previous grapheme-like cluster
+		end := len(runes)
+		start := end - 1
+		for start >= 0 && (isCombining(runes[start]) || isVariationSelector(runes[start])) {
+			start--
+		}
+		if start >= 0 && isRegionalIndicator(runes[start]) {
+			if start > 0 && isRegionalIndicator(runes[start-1]) {
+				start--
+			}
+		}
+		for {
+			if start > 0 && isZWJ(runes[start-1]) {
+				start -= 2
+				for start >= 0 && (isCombining(runes[start]) || isVariationSelector(runes[start])) {
+					start--
+				}
+				continue
+			}
+			break
+		}
+		if start < 0 {
+			start = 0
+		}
+		// Calculate total columns to clear
+		cols := 0
+		for i := start; i < end; i++ {
+			cols += runeDisplayWidth(runes[i])
+		}
+		// Update input
+		input.Reset()
+		input.WriteString(string(runes[:start]))
+		// Clear terminal cells
+		for i := 0; i < cols; i++ {
+			h.ui.write("\b \b")
+		}
+		return false, false
+	case 3: // Ctrl+C
+		h.ui.write("\r\n%sOperation canceled%s\r\n", h.ui.colors.BrightRed, h.ui.colors.Reset)
+		return true, true
+	default:
+		// Accept all printable characters including multibyte
+		if unicode.IsPrint(char) {
+			input.WriteRune(char)
+			h.ui.write("%s", string(char))
+		}
+		return false, false
+	}
 }
 
 // getLineInput provides fallback line-based input when raw mode is not available
@@ -604,7 +1210,7 @@ func (t *defaultTerminal) restore(fd int, state *term.State) error {
 }
 
 // NewUI creates a new UI with the provided git client
-func NewUI(gitClient git.Clienter) *UI {
+func NewUI(gitClient git.StatusInfoReader) *UI {
 	colors := NewANSIColors()
 
 	renderer := &Renderer{
@@ -652,18 +1258,20 @@ var commands = []CommandInfo{
 	{"add <file>", "Add a specific file to the index"},
 	{"add .", "Add all changes to index"},
 	{"add interactive", "Add changes interactively"},
-	{"add -p", "Add changes interactively (patch mode)"},
+	{"add patch", "Add changes interactively (patch mode)"},
 	{"branch current", "Show current branch name"},
 	{"branch checkout", "Switch to an existing branch"},
-	{"branch checkout-remote", "Create and checkout a local branch from the remote"},
+	{"branch checkout remote", "Create and checkout a local branch from the remote"},
 	{"branch create", "Create and checkout new branch"},
 	{"branch delete", "Delete local branch"},
-	{"branch delete-merged", "Delete local merged branch"},
+	{"branch delete merged", "Delete local merged branch"},
 	{"branch rename <old> <new>", "Rename a branch"},
 	{"branch move <branch> <commit>", "Move branch to specified commit"},
-	{"branch set-upstream <branch> <upstream>", "Set upstream for a branch"},
+	{"branch set upstream <branch> <upstream>", "Set upstream for a branch"},
 	{"branch info <branch>", "Show detailed branch information"},
-	{"branch list --verbose", "Show detailed branch listing"},
+	{"branch list verbose", "Show detailed branch listing"},
+	{"branch list local", "List local branches"},
+	{"branch list remote", "List remote branches"},
 	{"branch sort [date|name]", "List branches sorted by date or name"},
 	{"branch contains <commit>", "Show branches containing a commit"},
 	{"push current", "Push current branch from remote repository"},
@@ -673,10 +1281,10 @@ var commands = []CommandInfo{
 	{"log simple", "Show simple historical log"},
 	{"log graph", "Show log with graph"},
 	{"commit <message>", "Create commit with a message"},
-	{"commit allow-empty", "Create an empty commit"},
+	{"commit allow empty", "Create an empty commit"},
 	{"commit amend", "Amend previous commit (editor)"},
-	{"commit amend --no-edit", "Amend without editing commit message"},
-	{"fetch --prune", "Fetch and clean stale references"},
+	{"commit amend no-edit", "Amend without editing commit message"},
+	{"fetch prune", "Fetch and clean stale references"},
 	{"tag list", "List all tags"},
 	{"tag annotated <tag> <message>", "Create annotated tag"},
 	{"tag delete <tag>", "Delete tag"},
@@ -698,7 +1306,7 @@ var commands = []CommandInfo{
 	{"version", "Show current version"},
 	{"clean files", "Clean untracked files"},
 	{"clean dirs", "Clean untracked directories"},
-	{"clean-interactive", "Clean files interactively"},
+	{"clean interactive", "Clean files interactively"},
 	{"stash", "Stash current changes"},
 	{"stash list", "List all stashes"},
 	{"stash show", "Show changes in stash"},
@@ -719,8 +1327,11 @@ var commands = []CommandInfo{
 	{"stash store <object>", "Store stash object"},
 	{"status", "Show working tree status"},
 	{"status short", "Show concise status (porcelain format)"},
-	{"rebase -i", "Interactive rebase"},
-	{"rebase --interactive", "Interactive rebase"},
+	{"rebase interactive", "Interactive rebase"},
+	{"rebase <upstream>", "Rebase current branch onto <upstream>"},
+	{"rebase continue", "Continue an in-progress rebase"},
+	{"rebase abort", "Abort an in-progress rebase"},
+	{"rebase skip", "Skip current patch and continue"},
 	{"remote list", "List all remote repositories"},
 	{"remote add <name> <url>", "Add remote repository"},
 	{"remote remove <name>", "Remove remote repository"},
@@ -735,7 +1346,7 @@ var commands = []CommandInfo{
 
 // InteractiveUI provides an incremental search interactive UI with custom git client.
 // Returns the selected command as []string (nil if nothing selected)
-func InteractiveUI(gitClient git.Clienter) []string {
+func InteractiveUI(gitClient git.StatusInfoReader) []string {
 	ui := NewUI(gitClient)
 	return ui.Run()
 }
@@ -831,12 +1442,16 @@ func (r *Renderer) renderHeader(ui *UI) {
 	}
 
 	// Navigation subtitle
-	subtitle := fmt.Sprintf("%sType to search • %sCtrl+n/p%s navigate • %sCtrl+a/e%s move • %sEnter%s execute • %sCtrl+c%s quit%s",
+	subtitle := fmt.Sprintf("%sType to search • %sCtrl+n/p%s navigate • %s←/→%s move • %sCtrl+←/→%s word • %sCtrl+a/e%s line • %sEnter%s execute • %sCtrl+c%s quit%s",
 		r.colors.BrightBlack,
 		r.colors.BrightGreen+r.colors.Bold,
 		r.colors.BrightBlack,
 		r.colors.BrightCyan+r.colors.Bold,
 		r.colors.BrightBlack,
+		r.colors.BrightCyan+r.colors.Bold,
+		r.colors.BrightBlack,
+		r.colors.BrightCyan+r.colors.Bold,
+		r.colors.BrightBlack,
 		r.colors.BrightGreen+r.colors.Bold,
 		r.colors.BrightBlack,
 		r.colors.BrightGreen+r.colors.Bold,
@@ -870,14 +1485,15 @@ func (r *Renderer) renderSearchPrompt(ui *UI, state *UIState) {
 
 // formatInputWithCursor formats the input string with cursor position
 func (r *Renderer) formatInputWithCursor(state *UIState) string {
-	if len(state.input) == 0 {
+	if state.input == "" {
 		return fmt.Sprintf("%s█%s", r.colors.BrightWhite+r.colors.Bold, r.colors.Reset)
 	}
 
-	beforeCursor := state.input[:state.cursorPos]
-	afterCursor := state.input[state.cursorPos:]
+	inputRunes := []rune(state.input)
+	beforeCursor := string(inputRunes[:state.cursorPos])
+	afterCursor := string(inputRunes[state.cursorPos:])
 	cursor := "│"
-	if state.cursorPos >= len(state.input) {
+	if state.cursorPos >= utf8.RuneCountInString(state.input) {
 		cursor = "█"
 	}
 
@@ -911,6 +1527,10 @@ func (r *Renderer) renderNoMatches(ui *UI, state *UIState) {
 
 	// Available keybinds
 	keybinds := []struct{ key, desc string }{
+		{"←/→", "Move cursor"},
+		{"Ctrl+←/→", "Move by word"},
+		{"Option+←/→", "Move by word (macOS)"},
+		{"Option+Backspace", "Delete word (macOS)"},
 		{"Ctrl+u", "Clear all input"},
 		{"Ctrl+w", "Delete word"},
 		{"Ctrl+k", "Delete to end"},
@@ -1008,12 +1628,16 @@ func (r *Renderer) renderCommandItem(ui *UI, cmd CommandInfo, index, selected, m
 // renderFooter renders the navigation footer
 func (r *Renderer) renderFooter(ui *UI) {
 	r.writeEmptyLine()
-	footer := fmt.Sprintf("%s%sCtrl+n/p%s Navigate  %sCtrl+a/e%s Move  %sCtrl+u/w/k%s Edit  %sEnter%s Execute  %sCtrl+c%s Exit%s",
+	footer := fmt.Sprintf("%s%sCtrl+n/p%s Navigate  %s←/→%s Move  %sCtrl+←/→%s Word  %sCtrl+a/e%s Line  %sCtrl+u/w/k%s Edit  %sEnter%s Execute  %sCtrl+c%s Exit%s",
 		r.colors.BrightBlack,
 		r.colors.BrightGreen+r.colors.Bold,
 		r.colors.BrightBlack,
 		r.colors.BrightCyan+r.colors.Bold,
 		r.colors.BrightBlack,
+		r.colors.BrightCyan+r.colors.Bold,
+		r.colors.BrightBlack,
+		r.colors.BrightCyan+r.colors.Bold,
+		r.colors.BrightBlack,
 		r.colors.BrightYellow+r.colors.Bold,
 		r.colors.BrightBlack,
 		r.colors.BrightGreen+r.colors.Bold,
@@ -1118,7 +1742,7 @@ func (ui *UI) Run() []string {
 		}()
 	}
 
-	reader := bufio.NewReader(ui.stdin)
+	ui.reader = bufio.NewReader(ui.stdin)
 
 	for {
 		// Update filtered commands
@@ -1127,16 +1751,17 @@ func (ui *UI) Run() []string {
 		// Render the UI
 		ui.renderer.Render(ui, ui.state)
 
-		b, err := reader.ReadByte()
+		// Read UTF-8 rune instead of single byte
+		r, size, err := ui.reader.ReadRune()
 		if err != nil {
-			if err == io.EOF {
+			if errors.Is(err, io.EOF) {
 				return nil
 			}
 			continue
 		}
 
-		// Handle key input
-		shouldContinue, result := ui.handler.HandleKey(b, oldState)
+		// Handle key input with rune
+		shouldContinue, result := ui.handler.HandleKey(r, size == 1, oldState)
 		if !shouldContinue {
 			return result
 		}
